@@ -6,7 +6,7 @@
  * Created: Thu Apr 22 13:53:20 1999
  *
  * @author Nathan Stevens
- * @version 0.1;
+ * @version 0.3;
  */
 import java.awt.*;
 import java.awt.event.*;
@@ -16,6 +16,10 @@ import com.sun.java.swing.*;
 import com.sun.java.swing.text.*;
 import com.sun.java.swing.border.*;
 import com.sun.java.swing.event.*;
+//import javax.swing.*;
+//import javax.swing.text.*;
+//import javax.swing.border.*;
+//import javax.swing.event.*;
 
 public class BabelPanel extends JPanel implements ActionListener,
                         ListSelectionListener
@@ -497,13 +501,13 @@ public class BabelPanel extends JPanel implements ActionListener,
       if(e.getSource() == listi)
 	{
           // call the method that hadels list input model
-          int choice1 =  e.getFirstIndex() + 1;
+          int choice1 =  listi.getSelectedIndex() + 1;
           listInput(choice1);
 	}
       else if(e.getSource() == listo)
 	{
           // call method that handels listi stuff
-          int choice2 = e.getFirstIndex() + 1;
+          int choice2 = listo.getSelectedIndex() + 1;
           listOutput(choice2);
 	}
     }
@@ -519,10 +523,9 @@ public class BabelPanel extends JPanel implements ActionListener,
       // For this we have to open a FileDialog and get the String 
       // representation of the file and place it in to the file input
       // text field(tf3)
-      Frame tmpf  = new Frame("");
       String ifname;      
 
-      FileDialog fd  = new FileDialog(tmpf, "Input File name");
+      fDialog fd  = new fDialog(this, "Input File name");
       fd.setBackground(getPanelColor());
       fd.show();
  
@@ -729,7 +732,13 @@ public class BabelPanel extends JPanel implements ActionListener,
   public boolean isRetrieve()
     {
       return np.isRetrieve();
-    }  
+    }
+
+  // This method used in network mode only  
+  public String getInfile2()
+    {
+      return infile;
+    }
 }
 
 
