@@ -1,44 +1,27 @@
 
 /**
  * ChemToolFrame.java
- * This is used as the wrapper for tool Panels
+ * This is used as the frame for tool Panels such as BabelPanel etc. 
  *
  * Created: Thu Apr 22 14:13:31 1999
  *
  * @author Nathan Stevens
- * @version 0.1
+ * @version 0.2 
  */
 import java.awt.*;
 import java.awt.event.*;
 import com.sun.java.swing.*;
+//import javax.swing.*;
 
 public class ChemToolFrame extends JFrame 
 {  
-
-  public ChemToolFrame(String title, BabelPanel bp)
-    {
-      super(title);             // call the base contructor
-      addAppPanel(bp);
-    }
-  
-  public ChemToolFrame(String title, MopacPanel mp)
+  public ChemToolFrame(String title, JPanel panel)
     {
       super(title);
-      addAppPanel(mp);
-    }      
-
-  public ChemToolFrame(String title, DataFileEditorPanel dfe)
-    {
-     super(title);
-     addAppPanel(dfe);
+      addAppPanel(panel);
     }
   
-  public ChemToolFrame(String title, ConfigPanel cfp)
-    {
-      super(title);
-      addAppPanel(cfp);
-    }
- 
+  // Method to add JPanels to frame
   private void addAppPanel(JPanel panel)
     {  
       // set the layout manager
@@ -54,8 +37,16 @@ public class ChemToolFrame extends JFrame
       pack();
       setVisible(true);
     }
+
+  // Method to close the frame
+  public void Close()
+    {
+      setVisible(false);
+      dispose();
+    }
 }
 
+// This class just closes the window, but doesn't kill the JVM.
 class wCloser extends WindowAdapter
 {
   public void wCloser(WindowEvent e)
